==> gnome-games-1.0.51.tar.gz: gnome-games-1.0.51/gnometris/scoreframe.h <==
#ifndef __scoreframe_h__
#define __scoreframe_h__

/*
 * written by J. Marcin Gorycki <mgo@olicom.dk>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * For more details see the file COPYING.
 */

class ScoreFrame
{
public:
	ScoreFrame(int cmdlLevel);
	
	void show();
	void resetLines();	
	void incLines();	
	void checkLevel();
	void setLevel(int l);
		
	int getScore() {return score;}
	int getLines() {return lines;}
	int getLevel() {return level;}
	
	GtkWidget * getWidget()	{return w;}
	
private:
	GtkWidget *w;
	GtkWidget *scorew;
	GtkWidget *linesw;
	GtkWidget *levelw;
	GtkWidget *scoreLabel;
	GtkWidget *linesLabel;
	GtkWidget *levelLabel;
	GtkWidget *hbScore;
	GtkWidget *hbLines;
	GtkWidget *hbLevel;
	GtkWidget *vb;
	char b[20];

	int level;
	int score;
	int lines;
	int startingLevel;
	
	void setScore(int score);
};

#endif //__scoreframe_h__

==> gnome-games-1.2.0.tar.gz: gnome-games-1.2.0/gnometris/scoreframe.h <==
#ifndef __scoreframe_h__
#define __scoreframe_h__

/*
 * written by J. Marcin Gorycki <marcin.gorycki@intel.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * For more details see the file COPYING.
 */

class ScoreFrame
{
public:
	ScoreFrame(int cmdlLevel);
	
	void show();
	void resetLines();	
	void incLines();	
	void checkLevel();
	void setLevel(int l);
		
	int getScore() {return score;}
	int getLines() {return lines;}
	int getLevel() {return level;}
	
	GtkWidget * getWidget()	{return w;}
	
private:
	GtkWidget *w;
	GtkWidget *scorew;
	GtkWidget *linesw;
	GtkWidget *levelw;
	GtkWidget *scoreLabel;
	GtkWidget *linesLabel;
	GtkWidget *levelLabel;
	GtkWidget *hbScore;
	GtkWidget *hbLines;
	GtkWidget *hbLevel;
	GtkWidget *vb;
	char b[20];

	int level;
	int score;
	int lines;
	int startingLevel;
	
	void setScore(int score);
};

#endif //__scoreframe_h__
